@@ -6,7 +6,7 @@ package OpenGbg;
 
 # ABSTRACT: An interface to the Open Data API of Gothenburg
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.1401';
+our $VERSION = '0.1402';
 
 use OpenGbg::Elk;
 
@@ -124,16 +124,16 @@ OpenGbg - An interface to the Open Data API of Gothenburg
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/Csson/p5-OpenGbg"><img src="https://api.travis-ci.org/Csson/p5-OpenGbg.svg?branch=master" alt="Travis status" /></a>
-<a href="http://cpants.cpanauthors.org/dist/OpenGbg-0.1401"><img src="https://badgedepot.code301.com/badge/kwalitee/OpenGbg/0.1401" alt="Distribution kwalitee" /></a>
-<a href="http://matrix.cpantesters.org/?dist=OpenGbg%200.1401"><img src="https://badgedepot.code301.com/badge/cpantesters/OpenGbg/0.1401" alt="CPAN Testers result" /></a>
-<img src="https://img.shields.io/badge/coverage-78.1%-orange.svg" alt="coverage 78.1%" />
+<a href="http://cpants.cpanauthors.org/release/CSSON/OpenGbg-0.1402"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/OpenGbg/0.1402" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=OpenGbg%200.1402"><img src="http://badgedepot.code301.com/badge/cpantesters/OpenGbg/0.1402" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-78.7%-orange.svg" alt="coverage 78.7%" />
 </p>
 
 =end html
 
 =head1 VERSION
 
-Version 0.1401, released 2016-05-05.
+Version 0.1402, released 2016-08-12.
 
 =head1 SYNOPSIS
 
